"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _reactCodemirror = _interopRequireDefault(require("@uiw/react-codemirror"));

var _copyToClipboard = _interopRequireDefault(require("@uiw/copy-to-clipboard"));

var _reactSplit = _interopRequireDefault(require("@uiw/react-split"));

var _ThirdPartyButton = _interopRequireDefault(require("./ThirdPartyButton"));

var icon = _interopRequireWildcard(require("./icon"));

var _transform = require("./transform");

require("./monokai.css");

require("./index.css");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["React", "ReactDOM"],
    _excluded2 = ["style", "prefixCls", "language", "className", "editProps", "codePenOption", "codeSandboxOption", "code", "dependencies", "btnText", "btnHideText", "onlyEdit", "bordered", "noCode", "noPreview", "noScroll", "bgWhite"];

class CodePreview extends _react.default.PureComponent {
  constructor() {
    super(...arguments);
    this.demoDom = /*#__PURE__*/_react.default.createRef();
    this.editor = /*#__PURE__*/_react.default.createRef();
    this.language = '';
    this.initHeight = 3;
    this.playerId = "" + parseInt(String(Math.random() * 1e9), 10).toString(36);
    this.state = {
      errorMessage: '',
      fullScreen: false,
      copied: false,
      showEdit: false,
      width: 1
    };
  }

  componentDidMount() {
    var {
      language
    } = this.props;
    this.language = typeof language === 'string' ? language : language ? language.name || '' : '';

    if (!this.props.noPreview) {
      this.executeCode(this.props.code);
    }

    window.addEventListener("popstate", function (e) {
      document.body.style.overflow = 'inherit';
    }, false);
  }

  componentDidUpdate(prevProps) {
    var {
      language
    } = this.props;
    this.language = typeof language === 'string' ? language : language ? language.name || '' : '';

    if (prevProps.noPreview !== this.props.noPreview) {
      this.executeCode(this.props.code);
    }
  }

  executeCode(codeStr) {
    var _this = this;

    return (0, _asyncToGenerator2.default)(function* () {
      var {
        dependencies = {}
      } = _this.props;
      var {
        React: _React,
        ReactDOM: _ReactDOM
      } = dependencies,
          otherDeps = (0, _objectWithoutPropertiesLoose2.default)(dependencies, _excluded);

      if (!/(jsx|js)/.test(_this.language)) {
        return;
      }

      try {
        var deps = (0, _extends2.default)({
          context: _this,
          React: _React || _react.default,
          ReactDOM: _ReactDOM || _reactDom.default
        }, otherDeps); // const args = ['context', 'React', 'ReactDOM', 'Component'];

        var args = []; // const argv = [this, React, ReactDOM, Component];

        var argv = [];

        for (var key in deps) {
          args.push(key);
          argv.push(deps[key]);
        }

        codeStr = codeStr.replace('_mount_', "document.getElementById('" + _this.playerId + "')");
        var input = "" + codeStr;
        var {
          code
        } = (0, _transform.BabelTransform)(input);
        args.push(code || ''); // eslint-disable-next-line no-new-func

        new Function(...args).apply(null, argv);

        _this.setState({
          errorMessage: ''
        });
      } catch (err) {
        var message = '';

        if (err && err.message) {
          message = err.message;
        } else {
          message = JSON.stringify(err);
        }

        _this.setState({
          errorMessage: message
        });
      }
    })();
  }
  /**
   * onCopyCode
   */


  onCopyCode() {
    var {
      code
    } = this.props;
    (0, _copyToClipboard.default)(code || '', isCopy => {
      this.setState({
        copied: isCopy
      });
    });
    setTimeout(() => {
      this.setState({
        copied: false
      });
    }, 2000);
  }
  /**
   * onFullScreen
   */


  onFullScreen() {
    var {
      fullScreen
    } = this.state;
    this.setState({
      fullScreen: !fullScreen
    }, () => {
      document.body.style.overflow = !fullScreen ? 'hidden' : 'inherit';

      if (!fullScreen && this.demoDom.current) {
        this.demoDom.current.style.maxWidth = 'inherit';
      }
    });
  }

  initOldHeight() {
    var demo = this.demoDom.current;

    if (this.initHeight === 3 && demo) {
      this.initHeight = demo.clientHeight;
    }
  }
  /**
   * onSwitchSource
   */


  onSwitchSource() {
    var {
      width
    } = this.state;
    this.initOldHeight();
    this.setState({
      width: width === 1 ? '50%' : 1,
      showEdit: true
    }, () => {
      if (this.editor && this.editor.current && this.editor.current.editor) {
        this.editor.current.editor.setSize('100%', width !== 1 ? this.initHeight : '100%');
      }
    });
  }

  render() {
    var _this$props = this.props,
        {
      style,
      prefixCls,
      language,
      className,
      editProps,
      codePenOption,
      codeSandboxOption,
      code,
      btnText,
      btnHideText,
      onlyEdit,
      bordered,
      noCode,
      noPreview,
      noScroll,
      bgWhite
    } = _this$props,
        otherProps = (0, _objectWithoutPropertiesLoose2.default)(_this$props, _excluded2);
    var isOneItem = !noCode && !noPreview ? false : !noCode || !noPreview;
    var visiable = this.state.width === 1 ? false : [isOneItem ? 1 : 2];
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactSplit.default, (0, _extends2.default)({
      visiable: visiable,
      className: [className, prefixCls, noScroll ? prefixCls + "-noScroll" : null, isOneItem ? prefixCls + "-OneItem" : null, bordered ? prefixCls + "-bordered" : null, this.state.fullScreen ? prefixCls + "-fullScreen" : null].filter(Boolean).join(' ').trim(),
      style: (0, _extends2.default)({
        flex: 1
      }, style)
    }, otherProps, {
      children: [!noPreview && !onlyEdit && /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        ref: this.demoDom,
        className: [prefixCls + "-demo", !bgWhite ? prefixCls + "-demo-bgPlaid" : null, this.state.errorMessage ? prefixCls + "-demo-error" : null].filter(Boolean).join(' ').trim(),
        style: (0, _extends2.default)({
          flex: 1
        }, this.state.width === 1 ? {
          width: '100%'
        } : {}),
        children: [this.state.errorMessage && /*#__PURE__*/(0, _jsxRuntime.jsx)("pre", {
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)("code", {
            children: this.state.errorMessage
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          className: [prefixCls + "-demo-source", this.state.errorMessage ? 'error' : null].filter(Boolean).join(' ').trim(),
          id: this.playerId
        })]
      }), (!noCode || onlyEdit) && /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
        style: {
          overflow: 'hidden',
          width: onlyEdit ? '100%' : this.state.width
        },
        children: (this.state.showEdit || onlyEdit) && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactCodemirror.default, (0, _extends2.default)({
          value: (code || '').replace(/\n$/, ''),
          ref: this.editor,
          options: {
            theme: 'monokai',
            mode: language
          }
        }, editProps, {
          onChange: (editor, change) => {
            this.executeCode(editor.getValue());

            if (editProps && editProps.onChange) {
              editProps.onChange(editor, change);
            }
          }
        }))
      }), !isOneItem && !(noCode && noPreview) && !onlyEdit && /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        style: {
          flex: 1,
          width: 29
        },
        className: prefixCls + "-bar",
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_ThirdPartyButton.default, {
          prefixCls: prefixCls,
          codePenOption: codePenOption,
          codeSandboxOption: codeSandboxOption
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          className: prefixCls + "-bar-btn",
          onClick: this.onSwitchSource.bind(this),
          children: this.state.width === 1 ? btnText : btnHideText
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          className: [prefixCls + "-bar-iconbtns", this.state.copied ? prefixCls + "-bar-copied" : null].filter(Boolean).join(' ').trim(),
          onClick: this.onCopyCode.bind(this),
          children: icon.copy
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          className: [prefixCls + "-bar-iconbtns", this.state.fullScreen ? prefixCls + "-bar-copied" : null].filter(Boolean).join(' ').trim(),
          onClick: this.onFullScreen.bind(this),
          children: icon.full
        })]
      })]
    }));
  }

}

exports.default = CodePreview;
CodePreview.defaultProps = {
  prefixCls: 'w-code-preview',
  language: 'jsx',
  code: '',
  btnText: 'Code',
  btnHideText: 'Hide Editor',
  editProps: {},
  dependencies: {},
  noCode: false,
  bgWhite: false,
  onlyEdit: false,
  noPreview: false,
  bordered: true
};
//# sourceMappingURL=index.js.map